@@ -3,6 +3,7 @@ use std::cell::Cell;
 // nodes in the disjoint set forest of `DisjointSets`
 //
 // the only requirement is that the item that it holds is copyable
+#[derive(Debug, Eq, PartialEq)]
 pub struct Node<T>
 where
     T: Copy,
@@ -37,8 +38,11 @@ where
     pub fn get_parent(&self) -> Option<T> {
         self.parent.get()
     }
-    pub fn set_parent(&self, parent: T) {
-        self.parent.set(Some(parent));
+    pub fn set_parent<U>(&self, parent: &U)
+    where
+        U: AsRef<T>,
+    {
+        self.parent.set(Some(*parent.as_ref()));
     }
 
     //
@@ -49,3 +53,13 @@ where
         self.rank.set(rank);
     }
 }
+
+//
+impl<T> AsRef<T> for Node<T>
+where
+    T: Copy,
+{
+    fn as_ref(&self) -> &T {
+        &self.item
+    }
+}
