@@ -100,21 +100,21 @@ where
     /// sets.make_set(4).unwrap();
     /// sets.make_set(9).unwrap();
     ///
-    /// sets.union(1, 4).unwrap();
+    /// sets.union(&1, &4).unwrap();
     ///
     /// // equivalent items have the same representative
-    /// assert_eq!(sets.find_set(1).unwrap(), sets.find_set(1).unwrap());
-    /// assert_eq!(sets.find_set(4).unwrap(), sets.find_set(4).unwrap());
-    /// assert_eq!(sets.find_set(9).unwrap(), sets.find_set(9).unwrap());
+    /// assert_eq!(sets.find_set(&1).unwrap(), sets.find_set(&1).unwrap());
+    /// assert_eq!(sets.find_set(&4).unwrap(), sets.find_set(&4).unwrap());
+    /// assert_eq!(sets.find_set(&9).unwrap(), sets.find_set(&9).unwrap());
     ///
     /// // items in the same set have the same representative
-    /// assert_eq!(sets.find_set(1).unwrap(), sets.find_set(4).unwrap());
+    /// assert_eq!(sets.find_set(&1).unwrap(), sets.find_set(&4).unwrap());
     ///
     /// // items in different sets have different representatives
-    /// assert_ne!(sets.find_set(1).unwrap(), sets.find_set(9).unwrap());
-    /// assert_ne!(sets.find_set(4).unwrap(), sets.find_set(9).unwrap());
+    /// assert_ne!(sets.find_set(&1).unwrap(), sets.find_set(&9).unwrap());
+    /// assert_ne!(sets.find_set(&4).unwrap(), sets.find_set(&9).unwrap());
     /// ```
-    fn find_set(&self, item: T) -> Result<T>;
+    fn find_set(&self, item: &T) -> Result<T>;
 
     /// Create a new set that contains only `item` if `item` does not exist in any of the disjoint
     /// sets.
@@ -169,7 +169,7 @@ where
     /// sets.make_set(4).unwrap();
     /// sets.make_set(9).unwrap();
     ///
-    /// sets.union(1, 4).unwrap();
+    /// sets.union(&1, &4).unwrap();
     ///
     /// // the disjoint sets as a vector of sets
     /// let as_vec: Vec<HashSet<usize>> = sets.into_iter().collect();
@@ -188,7 +188,7 @@ where
     ///         .any(|set| set == &vec![1, 4].into_iter().collect::<HashSet<usize>>())
     /// );
     /// ```
-    fn union(&self, x: T, y: T) -> Result<()>;
+    fn union(&mut self, x: &T, y: &T) -> Result<()>;
 }
 
 //
